/*!
 * devextreme-angular
 * Version: 24.2.7
 * Build date: Mon Apr 28 2025
 *
 * Copyright (c) 2012 - 2025 Developer Express Inc. ALL RIGHTS RESERVED
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file in the root of the project for details.
 *
 * https://github.com/DevExpress/devextreme-angular
 */
import { TransferState, ElementRef, NgZone, OnDestroy, EventEmitter, OnChanges, DoCheck, SimpleChanges, QueryList } from '@angular/core';
import DataSource from 'devextreme/data/data_source';
import { dxGanttColumn, dxGanttContextMenu, dxGanttFilterRow, dxGanttHeaderFilter, ContentReadyEvent, ContextMenuPreparingEvent, CustomCommandEvent, DependencyDeletedEvent, DependencyDeletingEvent, DependencyInsertedEvent, DependencyInsertingEvent, DisposingEvent, InitializedEvent, OptionChangedEvent, ResourceAssignedEvent, ResourceAssigningEvent, ResourceDeletedEvent, ResourceDeletingEvent, ResourceInsertedEvent, ResourceInsertingEvent, ResourceManagerDialogShowingEvent, ResourceUnassignedEvent, ResourceUnassigningEvent, ScaleCellPreparedEvent, SelectionChangedEvent, TaskClickEvent, TaskDblClickEvent, TaskDeletedEvent, TaskDeletingEvent, TaskEditDialogShowingEvent, TaskInsertedEvent, TaskInsertingEvent, TaskMovingEvent, TaskUpdatedEvent, TaskUpdatingEvent, GanttScaleType, dxGanttSorting, dxGanttStripLine, GanttTaskTitlePosition, dxGanttToolbar } from 'devextreme/ui/gantt';
import { DataSourceOptions } from 'devextreme/data/data_source';
import { Store } from 'devextreme/data/store';
import { FirstDayOfWeek } from 'devextreme/common';
import DxGantt from 'devextreme/ui/gantt';
import { DxComponent, DxTemplateHost, NestedOptionHost, IterableDifferHelper, WatcherHelper } from 'devextreme-angular/core';
import { DxiColumnComponent } from 'devextreme-angular/ui/nested';
import { DxiStripLineComponent } from 'devextreme-angular/ui/nested';
import { DxiGanttColumnComponent } from 'devextreme-angular/ui/gantt/nested';
import { DxiGanttStripLineComponent } from 'devextreme-angular/ui/gantt/nested';
import type * as DxGanttTypes from "devextreme/ui/gantt_types";
import * as i0 from "@angular/core";
import * as i1 from "devextreme-angular/ui/nested";
import * as i2 from "devextreme-angular/ui/gantt/nested";
import * as i3 from "devextreme-angular/core";
/**
 * The Gantt is a UI component that displays the task flow and dependencies between tasks.

 */
export declare class DxGanttComponent extends DxComponent implements OnDestroy, OnChanges, DoCheck {
    private _watcherHelper;
    private _idh;
    instance: DxGantt;
    /**
     * Specifies the shortcut key that sets focus on the UI component.
    
     */
    get accessKey(): string | undefined;
    set accessKey(value: string | undefined);
    /**
     * Specifies whether the UI component changes its visual state as a result of user interaction.
    
     */
    get activeStateEnabled(): boolean;
    set activeStateEnabled(value: boolean);
    /**
     * Specifies whether users can select tasks in the Gantt.
    
     */
    get allowSelection(): boolean;
    set allowSelection(value: boolean);
    /**
     * An array of columns in the Gantt.
    
     */
    get columns(): Array<dxGanttColumn | string>;
    set columns(value: Array<dxGanttColumn | string>);
    /**
     * Configures the context menu settings.
    
     */
    get contextMenu(): dxGanttContextMenu;
    set contextMenu(value: dxGanttContextMenu);
    /**
     * Configures dependencies.
    
     */
    get dependencies(): {
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        predecessorIdExpr?: Function | string;
        successorIdExpr?: Function | string;
        typeExpr?: Function | string;
    };
    set dependencies(value: {
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        predecessorIdExpr?: Function | string;
        successorIdExpr?: Function | string;
        typeExpr?: Function | string;
    });
    /**
     * Specifies whether the UI component responds to user interaction.
    
     */
    get disabled(): boolean;
    set disabled(value: boolean);
    /**
     * Configures edit properties.
    
     */
    get editing(): {
        allowDependencyAdding?: boolean;
        allowDependencyDeleting?: boolean;
        allowResourceAdding?: boolean;
        allowResourceDeleting?: boolean;
        allowResourceUpdating?: boolean;
        allowTaskAdding?: boolean;
        allowTaskDeleting?: boolean;
        allowTaskResourceUpdating?: boolean;
        allowTaskUpdating?: boolean;
        enabled?: boolean;
    };
    set editing(value: {
        allowDependencyAdding?: boolean;
        allowDependencyDeleting?: boolean;
        allowResourceAdding?: boolean;
        allowResourceDeleting?: boolean;
        allowResourceUpdating?: boolean;
        allowTaskAdding?: boolean;
        allowTaskDeleting?: boolean;
        allowTaskResourceUpdating?: boolean;
        allowTaskUpdating?: boolean;
        enabled?: boolean;
    });
    /**
     * Specifies the global attributes to be attached to the UI component&apos;s container element.
    
     */
    get elementAttr(): Record<string, any>;
    set elementAttr(value: Record<string, any>);
    /**
     * Specifies the end date of the date interval in the Gantt chart.
    
     */
    get endDateRange(): Date;
    set endDateRange(value: Date);
    /**
     * Configures filter row settings.
    
     */
    get filterRow(): dxGanttFilterRow;
    set filterRow(value: dxGanttFilterRow);
    /**
     * Specifies the first day of a week.
    
     */
    get firstDayOfWeek(): FirstDayOfWeek | undefined;
    set firstDayOfWeek(value: FirstDayOfWeek | undefined);
    /**
     * Specifies whether the UI component can be focused using keyboard navigation.
    
     */
    get focusStateEnabled(): boolean;
    set focusStateEnabled(value: boolean);
    /**
     * Configures the header filter settings.
    
     */
    get headerFilter(): dxGanttHeaderFilter;
    set headerFilter(value: dxGanttHeaderFilter);
    /**
     * Specifies the UI component&apos;s height.
    
     */
    get height(): (() => number | string) | number | string | undefined;
    set height(value: (() => number | string) | number | string | undefined);
    /**
     * Specifies text for a hint that appears when a user pauses on the UI component.
    
     */
    get hint(): string | undefined;
    set hint(value: string | undefined);
    /**
     * Specifies whether the UI component changes its state when a user pauses on it.
    
     */
    get hoverStateEnabled(): boolean;
    set hoverStateEnabled(value: boolean);
    /**
     * Configures resource assignments.
    
     */
    get resourceAssignments(): {
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        resourceIdExpr?: Function | string;
        taskIdExpr?: Function | string;
    };
    set resourceAssignments(value: {
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        resourceIdExpr?: Function | string;
        taskIdExpr?: Function | string;
    });
    /**
     * Configures task resources.
    
     */
    get resources(): {
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        textExpr?: Function | string;
    };
    set resources(value: {
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        textExpr?: Function | string;
    });
    /**
     * Specifies the root task&apos;s identifier.
    
     */
    get rootValue(): any;
    set rootValue(value: any);
    /**
     * Specifies the zoom level of tasks in the Gantt chart.
    
     */
    get scaleType(): GanttScaleType;
    set scaleType(value: GanttScaleType);
    /**
     * Configures zoom range settings.
    
     */
    get scaleTypeRange(): {
        max?: GanttScaleType;
        min?: GanttScaleType;
    };
    set scaleTypeRange(value: {
        max?: GanttScaleType;
        min?: GanttScaleType;
    });
    /**
     * Allows you to select a row or determine which row is selected.
    
     */
    get selectedRowKey(): any | undefined;
    set selectedRowKey(value: any | undefined);
    /**
     * Specifies whether to display dependencies between tasks.
    
     */
    get showDependencies(): boolean;
    set showDependencies(value: boolean);
    /**
     * Specifies whether to display task resources.
    
     */
    get showResources(): boolean;
    set showResources(value: boolean);
    /**
     * Specifies whether to show/hide horizontal faint lines that separate tasks.
    
     */
    get showRowLines(): boolean;
    set showRowLines(value: boolean);
    /**
     * Configures sort settings.
    
     */
    get sorting(): dxGanttSorting;
    set sorting(value: dxGanttSorting);
    /**
     * Specifies the start date of the date interval in the Gantt chart.
    
     */
    get startDateRange(): Date;
    set startDateRange(value: Date);
    /**
     * Configures strip lines.
    
     */
    get stripLines(): Array<dxGanttStripLine>;
    set stripLines(value: Array<dxGanttStripLine>);
    /**
     * Specifies the number of the element when the Tab key is used for navigating.
    
     */
    get tabIndex(): number;
    set tabIndex(value: number);
    /**
     * Specifies custom content for the task.
    
     */
    get taskContentTemplate(): any;
    set taskContentTemplate(value: any);
    /**
     * Specifies the width of the task list in pixels.
    
     */
    get taskListWidth(): number;
    set taskListWidth(value: number);
    /**
     * Specifies custom content for the tooltip that displays the task&apos;s progress while the progress handler is resized in the UI.
    
     */
    get taskProgressTooltipContentTemplate(): any;
    set taskProgressTooltipContentTemplate(value: any);
    /**
     * Configures tasks.
    
     */
    get tasks(): {
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        endExpr?: Function | string;
        keyExpr?: Function | string;
        parentIdExpr?: Function | string;
        progressExpr?: Function | string;
        startExpr?: Function | string;
        titleExpr?: Function | string;
    };
    set tasks(value: {
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        endExpr?: Function | string;
        keyExpr?: Function | string;
        parentIdExpr?: Function | string;
        progressExpr?: Function | string;
        startExpr?: Function | string;
        titleExpr?: Function | string;
    });
    /**
     * Specifies custom content for the tooltip that displays the task&apos;s start and end time while the task is resized in the UI.
    
     */
    get taskTimeTooltipContentTemplate(): any;
    set taskTimeTooltipContentTemplate(value: any);
    /**
     * Specifies a task&apos;s title position.
    
     */
    get taskTitlePosition(): GanttTaskTitlePosition;
    set taskTitlePosition(value: GanttTaskTitlePosition);
    /**
     * Specifies custom content for the task tooltip.
    
     */
    get taskTooltipContentTemplate(): any;
    set taskTooltipContentTemplate(value: any);
    /**
     * Configures toolbar settings.
    
     */
    get toolbar(): dxGanttToolbar;
    set toolbar(value: dxGanttToolbar);
    /**
     * Configures validation properties.
    
     */
    get validation(): {
        autoUpdateParentTasks?: boolean;
        enablePredecessorGap?: boolean;
        validateDependencies?: boolean;
    };
    set validation(value: {
        autoUpdateParentTasks?: boolean;
        enablePredecessorGap?: boolean;
        validateDependencies?: boolean;
    });
    /**
     * Specifies whether the UI component is visible.
    
     */
    get visible(): boolean;
    set visible(value: boolean);
    /**
     * Specifies the UI component&apos;s width.
    
     */
    get width(): (() => number | string) | number | string | undefined;
    set width(value: (() => number | string) | number | string | undefined);
    /**
    
     * A function that is executed when the UI component is rendered and each time the component is repainted.
    
    
     */
    onContentReady: EventEmitter<ContentReadyEvent>;
    /**
    
     * A function that is executed before the context menu is rendered.
    
    
     */
    onContextMenuPreparing: EventEmitter<ContextMenuPreparingEvent>;
    /**
    
     * A function that is executed after a custom command item was clicked. Allows you to implement a custom command&apos;s functionality.
    
    
     */
    onCustomCommand: EventEmitter<CustomCommandEvent>;
    /**
    
     * A function that is executed when a dependency is deleted.
    
    
     */
    onDependencyDeleted: EventEmitter<DependencyDeletedEvent>;
    /**
    
     * A function that is executed before a dependency is deleted.
    
    
     */
    onDependencyDeleting: EventEmitter<DependencyDeletingEvent>;
    /**
    
     * A function that is executed when a dependency is inserted.
    
    
     */
    onDependencyInserted: EventEmitter<DependencyInsertedEvent>;
    /**
    
     * A function that is executed before a dependency is inserted.
    
    
     */
    onDependencyInserting: EventEmitter<DependencyInsertingEvent>;
    /**
    
     * A function that is executed before the UI component is disposed of.
    
    
     */
    onDisposing: EventEmitter<DisposingEvent>;
    /**
    
     * A function used in JavaScript frameworks to save the UI component instance.
    
    
     */
    onInitialized: EventEmitter<InitializedEvent>;
    /**
    
     * A function that is executed after a UI component property is changed.
    
    
     */
    onOptionChanged: EventEmitter<OptionChangedEvent>;
    /**
    
     * A function that is executed when a resource is assigned to a task.
    
    
     */
    onResourceAssigned: EventEmitter<ResourceAssignedEvent>;
    /**
    
     * A function that is executed before a resource is assigned to a task.
    
    
     */
    onResourceAssigning: EventEmitter<ResourceAssigningEvent>;
    /**
    
     * A function that is executed when a resource is deleted.
    
    
     */
    onResourceDeleted: EventEmitter<ResourceDeletedEvent>;
    /**
    
     * A function that is executed before a resource is deleted.
    
    
     */
    onResourceDeleting: EventEmitter<ResourceDeletingEvent>;
    /**
    
     * A function that is executed when a resource is inserted.
    
    
     */
    onResourceInserted: EventEmitter<ResourceInsertedEvent>;
    /**
    
     * A function that is executed before a resource is inserted.
    
    
     */
    onResourceInserting: EventEmitter<ResourceInsertingEvent>;
    /**
    
     * A function that is executed before the Resource Manager dialog is shown.
    
    
     */
    onResourceManagerDialogShowing: EventEmitter<ResourceManagerDialogShowingEvent>;
    /**
    
     * A function that is executed when a resource is unassigned from a task.
    
    
     */
    onResourceUnassigned: EventEmitter<ResourceUnassignedEvent>;
    /**
    
     * A function that is executed before a resource is unassigned from a task.
    
    
     */
    onResourceUnassigning: EventEmitter<ResourceUnassigningEvent>;
    /**
    
     * A function that is executed before a scale cell is prepared.
    
    
     */
    onScaleCellPrepared: EventEmitter<ScaleCellPreparedEvent>;
    /**
    
     * A function that is executed after users select a task or clear its selection.
    
    
     */
    onSelectionChanged: EventEmitter<SelectionChangedEvent>;
    /**
    
     * A function that is executed when a user clicks a task.
    
    
     */
    onTaskClick: EventEmitter<TaskClickEvent>;
    /**
    
     * A function that is executed when a user double-clicks a task.
    
    
     */
    onTaskDblClick: EventEmitter<TaskDblClickEvent>;
    /**
    
     * A function that is executed when a task is deleted.
    
    
     */
    onTaskDeleted: EventEmitter<TaskDeletedEvent>;
    /**
    
     * A function that is executed before a task is deleted.
    
    
     */
    onTaskDeleting: EventEmitter<TaskDeletingEvent>;
    /**
    
     * A function that is executed before the edit dialog is shown.
    
    
     */
    onTaskEditDialogShowing: EventEmitter<TaskEditDialogShowingEvent>;
    /**
    
     * A function that is executed when a task is inserted.
    
    
     */
    onTaskInserted: EventEmitter<TaskInsertedEvent>;
    /**
    
     * A function that is executed before a task is inserted.
    
    
     */
    onTaskInserting: EventEmitter<TaskInsertingEvent>;
    /**
    
     * A function that is executed before a task is moved.
    
    
     */
    onTaskMoving: EventEmitter<TaskMovingEvent>;
    /**
    
     * A function that is executed when a task is updated.
    
    
     */
    onTaskUpdated: EventEmitter<TaskUpdatedEvent>;
    /**
    
     * A function that is executed before a task is updated.
    
    
     */
    onTaskUpdating: EventEmitter<TaskUpdatingEvent>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    accessKeyChange: EventEmitter<string | undefined>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    activeStateEnabledChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    allowSelectionChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    columnsChange: EventEmitter<Array<dxGanttColumn | string>>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    contextMenuChange: EventEmitter<dxGanttContextMenu>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    dependenciesChange: EventEmitter<{
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        predecessorIdExpr?: Function | string;
        successorIdExpr?: Function | string;
        typeExpr?: Function | string;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    disabledChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    editingChange: EventEmitter<{
        allowDependencyAdding?: boolean;
        allowDependencyDeleting?: boolean;
        allowResourceAdding?: boolean;
        allowResourceDeleting?: boolean;
        allowResourceUpdating?: boolean;
        allowTaskAdding?: boolean;
        allowTaskDeleting?: boolean;
        allowTaskResourceUpdating?: boolean;
        allowTaskUpdating?: boolean;
        enabled?: boolean;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    elementAttrChange: EventEmitter<Record<string, any>>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    endDateRangeChange: EventEmitter<Date>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    filterRowChange: EventEmitter<dxGanttFilterRow>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    firstDayOfWeekChange: EventEmitter<FirstDayOfWeek | undefined>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    focusStateEnabledChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    headerFilterChange: EventEmitter<dxGanttHeaderFilter>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    heightChange: EventEmitter<(() => number | string) | number | string | undefined>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    hintChange: EventEmitter<string | undefined>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    hoverStateEnabledChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    resourceAssignmentsChange: EventEmitter<{
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        resourceIdExpr?: Function | string;
        taskIdExpr?: Function | string;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    resourcesChange: EventEmitter<{
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        keyExpr?: Function | string;
        textExpr?: Function | string;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    rootValueChange: EventEmitter<any>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    scaleTypeChange: EventEmitter<GanttScaleType>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    scaleTypeRangeChange: EventEmitter<{
        max?: GanttScaleType;
        min?: GanttScaleType;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    selectedRowKeyChange: EventEmitter<any | undefined>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    showDependenciesChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    showResourcesChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    showRowLinesChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    sortingChange: EventEmitter<dxGanttSorting>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    startDateRangeChange: EventEmitter<Date>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    stripLinesChange: EventEmitter<Array<dxGanttStripLine>>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    tabIndexChange: EventEmitter<number>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskContentTemplateChange: EventEmitter<any>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskListWidthChange: EventEmitter<number>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskProgressTooltipContentTemplateChange: EventEmitter<any>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    tasksChange: EventEmitter<{
        colorExpr?: Function | string;
        dataSource?: Array<any> | DataSource | DataSourceOptions | null | Store | string;
        endExpr?: Function | string;
        keyExpr?: Function | string;
        parentIdExpr?: Function | string;
        progressExpr?: Function | string;
        startExpr?: Function | string;
        titleExpr?: Function | string;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskTimeTooltipContentTemplateChange: EventEmitter<any>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskTitlePositionChange: EventEmitter<GanttTaskTitlePosition>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    taskTooltipContentTemplateChange: EventEmitter<any>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    toolbarChange: EventEmitter<dxGanttToolbar>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    validationChange: EventEmitter<{
        autoUpdateParentTasks?: boolean;
        enablePredecessorGap?: boolean;
        validateDependencies?: boolean;
    }>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    visibleChange: EventEmitter<boolean>;
    /**
    
     * This member supports the internal infrastructure and is not intended to be used directly from your code.
    
     */
    widthChange: EventEmitter<(() => number | string) | number | string | undefined>;
    get columnsChildren(): QueryList<DxiGanttColumnComponent>;
    set columnsChildren(value: QueryList<DxiGanttColumnComponent>);
    get stripLinesChildren(): QueryList<DxiGanttStripLineComponent>;
    set stripLinesChildren(value: QueryList<DxiGanttStripLineComponent>);
    get columnsLegacyChildren(): QueryList<DxiColumnComponent>;
    set columnsLegacyChildren(value: QueryList<DxiColumnComponent>);
    get stripLinesLegacyChildren(): QueryList<DxiStripLineComponent>;
    set stripLinesLegacyChildren(value: QueryList<DxiStripLineComponent>);
    constructor(elementRef: ElementRef, ngZone: NgZone, templateHost: DxTemplateHost, _watcherHelper: WatcherHelper, _idh: IterableDifferHelper, optionHost: NestedOptionHost, transferState: TransferState, platformId: any);
    protected _createInstance(element: any, options: any): DxGantt;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    setupChanges(prop: string, changes: SimpleChanges): void;
    ngDoCheck(): void;
    _setOption(name: string, value: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DxGanttComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DxGanttComponent, "dx-gantt", never, { "accessKey": { "alias": "accessKey"; "required": false; }; "activeStateEnabled": { "alias": "activeStateEnabled"; "required": false; }; "allowSelection": { "alias": "allowSelection"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "contextMenu": { "alias": "contextMenu"; "required": false; }; "dependencies": { "alias": "dependencies"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "editing": { "alias": "editing"; "required": false; }; "elementAttr": { "alias": "elementAttr"; "required": false; }; "endDateRange": { "alias": "endDateRange"; "required": false; }; "filterRow": { "alias": "filterRow"; "required": false; }; "firstDayOfWeek": { "alias": "firstDayOfWeek"; "required": false; }; "focusStateEnabled": { "alias": "focusStateEnabled"; "required": false; }; "headerFilter": { "alias": "headerFilter"; "required": false; }; "height": { "alias": "height"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "hoverStateEnabled": { "alias": "hoverStateEnabled"; "required": false; }; "resourceAssignments": { "alias": "resourceAssignments"; "required": false; }; "resources": { "alias": "resources"; "required": false; }; "rootValue": { "alias": "rootValue"; "required": false; }; "scaleType": { "alias": "scaleType"; "required": false; }; "scaleTypeRange": { "alias": "scaleTypeRange"; "required": false; }; "selectedRowKey": { "alias": "selectedRowKey"; "required": false; }; "showDependencies": { "alias": "showDependencies"; "required": false; }; "showResources": { "alias": "showResources"; "required": false; }; "showRowLines": { "alias": "showRowLines"; "required": false; }; "sorting": { "alias": "sorting"; "required": false; }; "startDateRange": { "alias": "startDateRange"; "required": false; }; "stripLines": { "alias": "stripLines"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "taskContentTemplate": { "alias": "taskContentTemplate"; "required": false; }; "taskListWidth": { "alias": "taskListWidth"; "required": false; }; "taskProgressTooltipContentTemplate": { "alias": "taskProgressTooltipContentTemplate"; "required": false; }; "tasks": { "alias": "tasks"; "required": false; }; "taskTimeTooltipContentTemplate": { "alias": "taskTimeTooltipContentTemplate"; "required": false; }; "taskTitlePosition": { "alias": "taskTitlePosition"; "required": false; }; "taskTooltipContentTemplate": { "alias": "taskTooltipContentTemplate"; "required": false; }; "toolbar": { "alias": "toolbar"; "required": false; }; "validation": { "alias": "validation"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "width": { "alias": "width"; "required": false; }; }, { "onContentReady": "onContentReady"; "onContextMenuPreparing": "onContextMenuPreparing"; "onCustomCommand": "onCustomCommand"; "onDependencyDeleted": "onDependencyDeleted"; "onDependencyDeleting": "onDependencyDeleting"; "onDependencyInserted": "onDependencyInserted"; "onDependencyInserting": "onDependencyInserting"; "onDisposing": "onDisposing"; "onInitialized": "onInitialized"; "onOptionChanged": "onOptionChanged"; "onResourceAssigned": "onResourceAssigned"; "onResourceAssigning": "onResourceAssigning"; "onResourceDeleted": "onResourceDeleted"; "onResourceDeleting": "onResourceDeleting"; "onResourceInserted": "onResourceInserted"; "onResourceInserting": "onResourceInserting"; "onResourceManagerDialogShowing": "onResourceManagerDialogShowing"; "onResourceUnassigned": "onResourceUnassigned"; "onResourceUnassigning": "onResourceUnassigning"; "onScaleCellPrepared": "onScaleCellPrepared"; "onSelectionChanged": "onSelectionChanged"; "onTaskClick": "onTaskClick"; "onTaskDblClick": "onTaskDblClick"; "onTaskDeleted": "onTaskDeleted"; "onTaskDeleting": "onTaskDeleting"; "onTaskEditDialogShowing": "onTaskEditDialogShowing"; "onTaskInserted": "onTaskInserted"; "onTaskInserting": "onTaskInserting"; "onTaskMoving": "onTaskMoving"; "onTaskUpdated": "onTaskUpdated"; "onTaskUpdating": "onTaskUpdating"; "accessKeyChange": "accessKeyChange"; "activeStateEnabledChange": "activeStateEnabledChange"; "allowSelectionChange": "allowSelectionChange"; "columnsChange": "columnsChange"; "contextMenuChange": "contextMenuChange"; "dependenciesChange": "dependenciesChange"; "disabledChange": "disabledChange"; "editingChange": "editingChange"; "elementAttrChange": "elementAttrChange"; "endDateRangeChange": "endDateRangeChange"; "filterRowChange": "filterRowChange"; "firstDayOfWeekChange": "firstDayOfWeekChange"; "focusStateEnabledChange": "focusStateEnabledChange"; "headerFilterChange": "headerFilterChange"; "heightChange": "heightChange"; "hintChange": "hintChange"; "hoverStateEnabledChange": "hoverStateEnabledChange"; "resourceAssignmentsChange": "resourceAssignmentsChange"; "resourcesChange": "resourcesChange"; "rootValueChange": "rootValueChange"; "scaleTypeChange": "scaleTypeChange"; "scaleTypeRangeChange": "scaleTypeRangeChange"; "selectedRowKeyChange": "selectedRowKeyChange"; "showDependenciesChange": "showDependenciesChange"; "showResourcesChange": "showResourcesChange"; "showRowLinesChange": "showRowLinesChange"; "sortingChange": "sortingChange"; "startDateRangeChange": "startDateRangeChange"; "stripLinesChange": "stripLinesChange"; "tabIndexChange": "tabIndexChange"; "taskContentTemplateChange": "taskContentTemplateChange"; "taskListWidthChange": "taskListWidthChange"; "taskProgressTooltipContentTemplateChange": "taskProgressTooltipContentTemplateChange"; "tasksChange": "tasksChange"; "taskTimeTooltipContentTemplateChange": "taskTimeTooltipContentTemplateChange"; "taskTitlePositionChange": "taskTitlePositionChange"; "taskTooltipContentTemplateChange": "taskTooltipContentTemplateChange"; "toolbarChange": "toolbarChange"; "validationChange": "validationChange"; "visibleChange": "visibleChange"; "widthChange": "widthChange"; }, ["columnsChildren", "stripLinesChildren", "columnsLegacyChildren", "stripLinesLegacyChildren"], never, false, never>;
}
export declare class DxGanttModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<DxGanttModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<DxGanttModule, [typeof DxGanttComponent], [typeof i1.DxiColumnModule, typeof i1.DxoFormatModule, typeof i1.DxoHeaderFilterModule, typeof i1.DxoSearchModule, typeof i1.DxoContextMenuModule, typeof i1.DxiItemModule, typeof i1.DxoDependenciesModule, typeof i1.DxoEditingModule, typeof i1.DxoFilterRowModule, typeof i1.DxoOperationDescriptionsModule, typeof i1.DxoTextsModule, typeof i1.DxoResourceAssignmentsModule, typeof i1.DxoResourcesModule, typeof i1.DxoScaleTypeRangeModule, typeof i1.DxoSortingModule, typeof i1.DxiStripLineModule, typeof i1.DxoTasksModule, typeof i1.DxoToolbarModule, typeof i1.DxoValidationModule, typeof i2.DxiGanttColumnModule, typeof i2.DxoGanttColumnHeaderFilterModule, typeof i2.DxoGanttColumnHeaderFilterSearchModule, typeof i2.DxoGanttContextMenuModule, typeof i2.DxiGanttContextMenuItemModule, typeof i2.DxiGanttContextMenuItemItemModule, typeof i2.DxoGanttDependenciesModule, typeof i2.DxoGanttEditingModule, typeof i2.DxoGanttFilterRowModule, typeof i2.DxoGanttFormatModule, typeof i2.DxoGanttGanttHeaderFilterModule, typeof i2.DxoGanttGanttHeaderFilterSearchModule, typeof i2.DxoGanttHeaderFilterModule, typeof i2.DxiGanttItemModule, typeof i2.DxoGanttOperationDescriptionsModule, typeof i2.DxoGanttResourceAssignmentsModule, typeof i2.DxoGanttResourcesModule, typeof i2.DxoGanttScaleTypeRangeModule, typeof i2.DxoGanttSearchModule, typeof i2.DxoGanttSortingModule, typeof i2.DxiGanttStripLineModule, typeof i2.DxoGanttTasksModule, typeof i2.DxoGanttTextsModule, typeof i2.DxoGanttToolbarModule, typeof i2.DxiGanttToolbarItemModule, typeof i2.DxoGanttValidationModule, typeof i3.DxIntegrationModule, typeof i3.DxTemplateModule], [typeof DxGanttComponent, typeof i1.DxiColumnModule, typeof i1.DxoFormatModule, typeof i1.DxoHeaderFilterModule, typeof i1.DxoSearchModule, typeof i1.DxoContextMenuModule, typeof i1.DxiItemModule, typeof i1.DxoDependenciesModule, typeof i1.DxoEditingModule, typeof i1.DxoFilterRowModule, typeof i1.DxoOperationDescriptionsModule, typeof i1.DxoTextsModule, typeof i1.DxoResourceAssignmentsModule, typeof i1.DxoResourcesModule, typeof i1.DxoScaleTypeRangeModule, typeof i1.DxoSortingModule, typeof i1.DxiStripLineModule, typeof i1.DxoTasksModule, typeof i1.DxoToolbarModule, typeof i1.DxoValidationModule, typeof i2.DxiGanttColumnModule, typeof i2.DxoGanttColumnHeaderFilterModule, typeof i2.DxoGanttColumnHeaderFilterSearchModule, typeof i2.DxoGanttContextMenuModule, typeof i2.DxiGanttContextMenuItemModule, typeof i2.DxiGanttContextMenuItemItemModule, typeof i2.DxoGanttDependenciesModule, typeof i2.DxoGanttEditingModule, typeof i2.DxoGanttFilterRowModule, typeof i2.DxoGanttFormatModule, typeof i2.DxoGanttGanttHeaderFilterModule, typeof i2.DxoGanttGanttHeaderFilterSearchModule, typeof i2.DxoGanttHeaderFilterModule, typeof i2.DxiGanttItemModule, typeof i2.DxoGanttOperationDescriptionsModule, typeof i2.DxoGanttResourceAssignmentsModule, typeof i2.DxoGanttResourcesModule, typeof i2.DxoGanttScaleTypeRangeModule, typeof i2.DxoGanttSearchModule, typeof i2.DxoGanttSortingModule, typeof i2.DxiGanttStripLineModule, typeof i2.DxoGanttTasksModule, typeof i2.DxoGanttTextsModule, typeof i2.DxoGanttToolbarModule, typeof i2.DxiGanttToolbarItemModule, typeof i2.DxoGanttValidationModule, typeof i3.DxTemplateModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<DxGanttModule>;
}
export { DxGanttTypes };
